@@ -1,23 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1b5pre"
-#define PACKAGE_STRING "am-utils 6.1b5pre"
+#define PACKAGE_VERSION "6.1-rc4"
+#define PACKAGE_STRING "am-utils 6.1-rc4"
 #define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define HOST_CPU "powerpc"
 #define HOST_VENDOR "apple"
-#define HOST_OS "darwin7.7.0"
-#define HOST_OS_NAME "darwin7"
-#define HOST_OS_VERSION "7.7.0"
-#define HOST_ARCH "Power Macintosh"
+#define HOST_OS "macosx-10.3.8"
+#define HOST_OS_NAME "macosx-10"
+#define HOST_OS_VERSION "10.3.8"
+#define HOST_ARCH "powerpc"
+#define DISTRO_NAME "none"
 #define HOST_NAME "a-osx.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Wed Feb 23 22:35:29 EST 2005"
+#define CONFIG_DATE "Wed May 11 14:41:33 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1b5pre"
+#define PACKAGE_VERSION "6.1-rc4"
 #define PACKAGE_BUGREPORT "am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1b5pre"
+#define VERSION "6.1-rc4"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -30,7 +31,7 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "7.7.0"
+#define HOST_HEADER_VERSION "10.3.8"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBLDAP 1
 #define HAVE_LDAP_ENABLE_CACHE 1
@@ -80,10 +81,11 @@
 #define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
 #define HAVE_STRCHR 1
-#define HAVE_STRCSPN 1
 #define HAVE_STRCASECMP 1
+#define HAVE_STRCSPN 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
 #define HAVE_SVC_GETREQ 1
@@ -99,6 +101,7 @@
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_POINTER 1
@@ -161,6 +164,7 @@
 #define HAVE_LBER_H 1
 #define HAVE_LDAP_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
@@ -218,6 +222,7 @@
 #define HAVE_EXTERN_SETITIMER 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
@@ -240,10 +245,17 @@
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_WAITPID 1
+#define HAVE_MAP_EXEC 1
+#define HAVE_LDAP_OPEN 1
 #define HAVE_MAP_LDAP 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_NFS 1
@@ -253,7 +265,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -300,3 +311,4 @@
 #define MNT2_CDFS_OPT_GENS 0x2
 #define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
